# Django lazy managers

[![Coverage Status][coverage-badge]][coverage]
[![GitHub Workflow Status][status-badge]][status]
[![PyPI][pypi-badge]][pypi]
[![GitHub][licence-badge]][licence]
[![GitHub Last Commit][repo-badge]][repo]
[![GitHub Issues][issues-badge]][issues]
[![Downloads][downloads-badge]][pypi]
[![Python Version][version-badge]][pypi]

[coverage-badge]: https://coveralls.io/repos/github/MrThearMan/django-lazy-managers/badge.svg?branch=main
[status-badge]: https://img.shields.io/github/actions/workflow/status/MrThearMan/django-lazy-managers/test.yml?branch=main
[pypi-badge]: https://img.shields.io/pypi/v/django-lazy-managers
[licence-badge]: https://img.shields.io/github/license/MrThearMan/django-lazy-managers
[repo-badge]: https://img.shields.io/github/last-commit/MrThearMan/django-lazy-managers
[issues-badge]: https://img.shields.io/github/issues-raw/MrThearMan/django-lazy-managers
[version-badge]: https://img.shields.io/pypi/pyversions/django-lazy-managers
[downloads-badge]: https://img.shields.io/pypi/dm/django-lazy-managers

[coverage]: https://coveralls.io/github/MrThearMan/django-lazy-managers?branch=main
[status]: https://github.com/MrThearMan/django-lazy-managers/actions/workflows/test.yml
[pypi]: https://pypi.org/project/django-lazy-managers
[licence]: https://github.com/MrThearMan/django-lazy-managers/blob/main/LICENSE
[repo]: https://github.com/MrThearMan/django-lazy-managers/commits/main
[issues]: https://github.com/MrThearMan/django-lazy-managers/issues

```shell
pip install django-lazy-managers
```

---

**Documentation**: [https://mrthearman.github.io/django-lazy-managers/](https://mrthearman.github.io/django-lazy-managers/)

**Source Code**: [https://github.com/MrThearMan/django-lazy-managers/](https://github.com/MrThearMan/django-lazy-managers/)

**Contributing**: [https://github.com/MrThearMan/django-lazy-managers/blob/main/CONTRIBUTING.md](https://github.com/MrThearMan/django-lazy-managers/blob/main/CONTRIBUTING.md)

---

Lazy model managers for Django
